==> design.plone.ioprenoto-1.1.5-py3-none-any.whl: design/plone/ioprenoto/restapi/serializers/ovverrides/prenotazioniFolder.py <==
from design.plone.ioprenoto.interfaces import IDesignPloneIoprenotoLayer
from plone import api
from plone.restapi.interfaces import ISerializeToJson
from plone.restapi.interfaces import ISerializeToJsonSummary
from plone.restapi.serializer.dxcontent import SerializeFolderToJson
from plone.restapi.serializer.summary import DefaultJSONSummarySerializer
from redturtle.prenotazioni.content.prenotazioni_folder import IPrenotazioniFolder
from zope.component import adapter
from zope.interface import implementer


PRENOTAZIONI_MANAGE_PERMISSION = "redturtle.prenotazioni: Manage Prenotazioni"
# TODO: move to registry
PRENOTAZIONE_APPUNTAMENTO_ADDRESS = "prenotazione-appuntamenti-uffici"


@implementer(ISerializeToJsonSummary)
@adapter(IPrenotazioniFolder, IDesignPloneIoprenotoLayer)
class SerializePrenotazioniFolderToJsonSummary(DefaultJSONSummarySerializer):
    def __call__(self, *args, **kwargs):
        resp = super().__call__(*args, **kwargs)
        if not api.user.has_permission(
            PRENOTAZIONI_MANAGE_PERMISSION,
            obj=self.context,
        ):
            # XXX: this is a workaround to avoid the Unauthorized exception
            return {
                "@components": resp["@components"],
                "@id": resp["@id"],
                "@type": resp["@type"],
                "layout": resp["layout"],
                "title": resp["title"],
                "error": "Unauthorized",
                "anonymous": api.user.is_anonymous(),
            }
        return resp


@implementer(ISerializeToJson)
@adapter(IPrenotazioniFolder, IDesignPloneIoprenotoLayer)
class SerializePrenotazioniFolderToJson(SerializeFolderToJson):
    def __call__(self, *args, **kwargs):
        resp = super().__call__(*args, **kwargs)
        if not api.user.has_permission(
            PRENOTAZIONI_MANAGE_PERMISSION,
            obj=self.context,
        ):
            # XXX: this is a workaround to avoid the Unauthorized exception
            return {
                "@components": resp["@components"],
                "@id": resp["@id"],
                "@type": resp["@type"],
                "layout": resp["layout"],
                "title": resp["title"],
                "error": "Unauthorized",
                "anonymous": api.user.is_anonymous(),
            }
        return resp

==> design.plone.ioprenoto-1.2.1-py3-none-any.whl: design/plone/ioprenoto/restapi/serializers/ovverrides/prenotazioniFolder.py <==
from plone import api
from plone.restapi.interfaces import ISerializeToJson, ISerializeToJsonSummary
from plone.restapi.serializer.summary import DefaultJSONSummarySerializer
from redturtle.prenotazioni.content.prenotazioni_folder import IPrenotazioniFolder
from redturtle.prenotazioni.restapi.serializers.adapters.prenotazioni_folder import (
    PrenotazioniFolderSerializer,
)
from zope.component import adapter
from zope.interface import implementer

from design.plone.ioprenoto import PRENOTAZIONI_MANAGE_PERMISSION
from design.plone.ioprenoto.interfaces import IDesignPloneIoprenotoLayer

# TODO: move to registry
PRENOTAZIONE_APPUNTAMENTO_ADDRESS = "prenotazione-appuntamenti-uffici"


@implementer(ISerializeToJsonSummary)
@adapter(IPrenotazioniFolder, IDesignPloneIoprenotoLayer)
class SerializePrenotazioniFolderToJsonSummary(DefaultJSONSummarySerializer):
    def __call__(self, *args, **kwargs):
        resp = super().__call__(*args, **kwargs)
        if not api.user.has_permission(
            PRENOTAZIONI_MANAGE_PERMISSION,
            obj=self.context,
        ):
            # XXX: this is a workaround to avoid the Unauthorized exception
            return {
                "@components": resp.get("@components", {}),
                "@id": resp.get("@id", ""),
                "@type": resp.get("@type", ""),
                "layout": resp.get("@layout", ""),
                "title": resp.get("@title", ""),
                "error": "Unauthorized",
                "anonymous": api.user.is_anonymous(),
            }
        return resp


@implementer(ISerializeToJson)
@adapter(IPrenotazioniFolder, IDesignPloneIoprenotoLayer)
class SerializePrenotazioniFolderToJson(PrenotazioniFolderSerializer):
    def __call__(self, *args, **kwargs):
        resp = super().__call__(*args, **kwargs)
        if not api.user.has_permission(
            PRENOTAZIONI_MANAGE_PERMISSION,
            obj=self.context,
        ):
            # XXX: this is a workaround to avoid the Unauthorized exception
            return {
                "@components": resp["@components"],
                "@id": resp["@id"],
                "@type": resp["@type"],
                "layout": resp["layout"],
                "title": resp["title"],
                "error": "Unauthorized",
                "anonymous": api.user.is_anonymous(),
            }
        return resp
